from distutils.core import setup

setup(
  name='tannin',
  version='0.0.2',
  author='Unknown',
  author_email='unknown@example.com',
  url='https://github.com',
  license="MIT",
  long_description="nylon is a helper library",
  packages=['tannin'],
  scripts=[]
)

